==> vbimage-0.1.32-py3-none-any.whl: vbimage/grid.py <==

import click
import os
from PIL import Image, ImageDraw



@click.command(
        help="Adds background to any transparent image"
        )
@click.option(
        '-i', 
        '--inputimage', 
        type=click.Path(),
        default="./main.png",
        show_default=True,
        help="Front Image"
        )
@click.option(
        '-o', 
        '--outputimage', 
        type=click.Path(),
        default="./main_grided.png",
        show_default=True,
        help="Resized output image"
        )
@click.option(
        '-s',
        '--step',
        type=click.Tuple([int, int]),
        default=(10, 10),
        show_default=True,
        help='Number of division.'
        )
@click.option(
        '-S',
        '--stroke_width',
        type=click.INT,
        default=2,
        show_default=True,
        help='Stroke width of the lines.'
        )
def grid(inputimage, outputimage, step, stroke_width):
    
    with Image.open(inputimage) as im:
        W = im.width
        H = im.height
        draw = ImageDraw.Draw(im)
        for i in range(step[0]):
            draw.line([(i*W/step[0], H), (i*W/step[0], 0)], fill='black', width=stroke_width)
            if (i%2) != 0:
                draw.text((i*W/step[0], H-50), f'{i*W/step[0]:0f}', size=50, align="center")
    
        for j in range(step[1]):
            draw.line([(0, j*H/step[1]), (W, j*H/step[1])], fill='black', width=stroke_width)
            if (j%2) != 0:
                draw.text((50, j*H/step[1]), f'{j*H/step[1]:0f}', size=50, align="center")


        im.save(outputimage, format="png")

    click.echo(f'{inputimage} is grided to step size {step} as {outputimage}.')

#    with click.progressbar([1, 2, 3]) as bar:
#        for x in bar:
#            print(f"sleep({x})...")
#            time.sleep(x)

==> vbimage-0.1.36-py3-none-any.whl: vbimage/grid.py <==

import click
import os
from PIL import Image, ImageDraw, ImageFont



@click.command(
        help="Adds background to any transparent image"
        )
@click.option(
        '-i', 
        '--inputimage', 
        type=click.Path(),
        default="./main.png",
        show_default=True,
        help="Front Image"
        )
@click.option(
        '-o', 
        '--outputimage', 
        type=click.Path(),
        default="./main_grided.png",
        show_default=True,
        help="Resized output image"
        )
@click.option(
        '-s',
        '--step',
        type=click.Tuple([int, int]),
        default=(10, 10),
        show_default=True,
        help='Number of division.'
        )
@click.option(
        '-S',
        '--stroke_width',
        type=click.INT,
        default=2,
        show_default=True,
        help='Stroke width of the lines.'
        )
def grid(inputimage, outputimage, step, stroke_width):
    
    with Image.open(inputimage) as im:
        W = im.width
        H = im.height
        if step[0] > 15:
            font_size = 25
        else:
            font_size = 50
        draw = ImageDraw.Draw(im)
        fnt = ImageFont.truetype("/System/Library/Fonts/Supplemental/Courier New.ttf", font_size)
        for i in range(step[0]):
            draw.line([(i*W/step[0], H), (i*W/step[0], 0)], fill='black', width=stroke_width)
            draw.text((i*W/step[0], H-50), f'{int(i*W/step[0])}', font=fnt, align='right')
    
        for j in range(step[1]):
            draw.line([(0, j*H/step[1]), (W, j*H/step[1])], fill='black', width=stroke_width)
            draw.text((50, j*H/step[1]), f'{int(j*H/step[1])}', font=fnt, align='left')


        im.save(outputimage, format="png")

    click.echo(f'{inputimage} is grided to step size {step} as {outputimage}.')

#    with click.progressbar([1, 2, 3]) as bar:
#        for x in bar:
#            print(f"sleep({x})...")
#            time.sleep(x)
